@@ -294,7 +294,7 @@ TEST(ParserTest, file) {
     }
 }
 
-// This test loads the all-keys.json file and check global parameters.
+// This test loads the all-keys.json file and checks global parameters.
 TEST(ParserTest, globalParameters) {
     ConstElementPtr json;
     Parser4Context ctx;
@@ -762,7 +762,8 @@ TEST(ParserTest, mapEntries) {
     loadFile(sample_dir + "reservations.json", sample_json);
     loadFile(sample_dir + "all-keys-netconf.json", sample_json);
     KeywordSet sample_keys = {
-        "hosts-database"
+        "hosts-database",
+        "reservation-mode"
     };
     // Recursively extract keywords.
     static void (*extract)(ConstElementPtr, KeywordSet&) =
