@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,6 +10,7 @@
 #include <dhcpsrv/lease_mgr_factory.h>
 #include <dhcpsrv/pgsql_lease_mgr.h>
 #include <dhcpsrv/testutils/test_utils.h>
+#include <dhcpsrv/testutils/pgsql_generic_backend_unittest.h>
 #include <dhcpsrv/tests/generic_lease_mgr_unittest.h>
 #include <exceptions/exceptions.h>
 #include <pgsql/pgsql_connection.h>
@@ -110,10 +111,10 @@ public:
 ///
 /// This test checks if the PgSqlLeaseMgr can be instantiated.  This happens
 /// only if the database can be opened.  Note that this is not part of the
-/// PgSqlLeaseMgr test fixure set.  This test checks that the database can be
+/// PgSqlLeaseMgr test fixture set.  This test checks that the database can be
 /// opened: the fixtures assume that and check basic operations.
 TEST(PgSqlOpenTest, OpenDatabase) {
-    // Explicitely disable Multi-Threading.
+    // Explicitly disable Multi-Threading.
     MultiThreadingMgr::instance().setMode(false);
 
     // Schema needs to be created for the test to work.
@@ -642,7 +643,7 @@ TEST_F(PgSqlLeaseMgrTest, lease6InvalidHostnameMultiThreading) {
 /// @brief Verify that large IAID values work correctly.
 ///
 /// Adds lease with a large IAID to the database and verifies it can
-/// fetched correclty.
+/// fetched correctly.
 TEST_F(PgSqlLeaseMgrTest, leases6LargeIaidCheck) {
     testLease6LargeIaidCheck();
 }
@@ -1028,4 +1029,23 @@ TEST_F(PgSqlLeaseMgrTest, leaseStatsQueryAttribution6MultiThreading) {
     testLeaseStatsQueryAttribution6();
 }
 
+/// @brief This test is a basic check for the generic backend test class,
+///        rather than any production code check.
+TEST_F(PgSqlGenericBackendTest, leaseCount) {
+
+    // Create database connection parameter list
+    DatabaseConnection::ParameterMap params;
+    params["name"] = "keatest";
+    params["user"] = "keatest";
+    params["password"] = "keatest";
+
+    // Create and open the database connection
+    PgSqlConnection conn(params);
+    conn.openDatabase();
+
+    // Check that the countRows is working. It's used extensively in other
+    // tests, so basic check is enough here.
+    EXPECT_EQ(0, countRows(conn, "lease4"));
+}
+
 }  // namespace
