@@ -21,6 +21,7 @@ using namespace isc::asiolink;
 using namespace isc::dhcp;
 using namespace isc::data;
 using namespace isc::process;
+using namespace isc::util;
 
 // Those are the tests for SrvConfig storage. Right now they are minimal,
 // but the number is expected to grow significantly once we migrate more
@@ -142,7 +143,7 @@ void
 SrvConfigTest::addSubnet4(const unsigned int index) {
     if (index >= TEST_SUBNETS_NUM) {
         FAIL() << "Subnet index " << index << "out of range (0.."
-               << TEST_SUBNETS_NUM << "): " << "unable to add IPv4 subnet";
+               << TEST_SUBNETS_NUM << "): unable to add IPv4 subnet";
     }
     // std::advance is not available for this iterator.
     auto it = test_subnets4_.begin();
@@ -156,7 +157,7 @@ void
 SrvConfigTest::addSubnet6(const unsigned int index) {
     if (index >= TEST_SUBNETS_NUM) {
         FAIL() << "Subnet index " << index << "out of range (0.."
-               << TEST_SUBNETS_NUM << "): " << "unable to add IPv6 subnet";
+               << TEST_SUBNETS_NUM << "): unable to add IPv6 subnet";
     }
     // std::advance is not available for this iterator.
     auto it = test_subnets6_.begin();
