@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2016-2021 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,6 +8,7 @@
 
 #include <pgsql/pgsql_connection.h>
 #include <pgsql/pgsql_exchange.h>
+#include <pgsql/testutils/pgsql_schema.h>
 
 #include <boost/lexical_cast.hpp>
 
@@ -18,6 +19,7 @@
 
 using namespace isc;
 using namespace isc::db;
+using namespace isc::util;
 
 namespace {
 
@@ -71,6 +73,9 @@ TEST(PsqlBindArray, addDataTest) {
 
         // Add the vector
         b.add(bytes);
+
+        // Add an empty string.
+        b.add(std::string(""));
     }
 
     // We've left bind scope, everything should be intact.
@@ -85,13 +90,46 @@ TEST(PsqlBindArray, addDataTest) {
         "7 : \"FALSE\"\n"
         "8 : \"3221360418\"\n"
         "9 : \"3001::1\"\n"
-        "10 : 0x0102030405060708090a\n";
+        "10 : 0x0102030405060708090a\n"
+        "11 : empty\n";
+
+    EXPECT_EQ(expected, b.toText());
+}
+
+/// @brief Verifies the ability to add Triplets to
+/// the bind array.
+TEST(PsqlBindArray, addTriplet) {
+
+    PsqlBindArray b;
+
+    // Add all the items within a different scope. Everything should
+    // still be valid once we exit this scope.
+    {
+        Triplet<uint32_t> empty;
+        Triplet<uint32_t> not_empty(1,2,3);
+
+        // Add an unspecified triplet value.
+        b.add(empty);
+        b.add(not_empty);
+        b.addMin(empty);
+        b.addMin(not_empty);
+        b.addMax(empty);
+        b.addMax(not_empty);
+    }
+
+    // We've left bind scope, everything should be intact.
+    EXPECT_EQ(6, b.size());
+    std::string expected =
+        "0 : empty\n"
+        "1 : \"2\"\n"
+        "2 : empty\n"
+        "3 : \"1\"\n"
+        "4 : empty\n"
+        "5 : \"3\"\n";
 
     EXPECT_EQ(expected, b.toText());
 }
 
-/// @brief Defines a pointer to a PgSqlConnection
-typedef boost::shared_ptr<PgSqlConnection> PgSqlConnectionPtr;
 /// @brief Defines a pointer to a PgSqlResult
 typedef boost::shared_ptr<PgSqlResult> PgSqlResultPtr;
 
@@ -130,7 +168,7 @@ public:
     /// the table (if present) and then recreates it.
     PgSqlBasicsTest() : expectedColNames_(NUM_BASIC_COLS) {
         // Create database connection parameter list
-        PgSqlConnection::ParameterMap params;
+        DatabaseConnection::ParameterMap params;
         params["name"] = "keatest";
         params["user"] = "keatest";
         params["password"] = "keatest";
@@ -302,6 +340,53 @@ public:
 #define FETCH_ROWS(a,b) (fetchRows(a,b,__LINE__))
 #define WIPE_ROWS(a) (RUN_SQL(a, "DELETE FROM BASICS", PGRES_COMMAND_OK))
 
+// A small extension of PgSqlBasicsTest that instantiates the actual Kea schema.
+// Those tests tend to be a bit heavy (especially with the CB and its tables),
+// so please consider adding your tests in PgSqlBasicsTest, unless you really need
+// the full schema.
+class PgSqlSchemaTest: public PgSqlBasicsTest {
+public:
+    PgSqlSchemaTest() : PgSqlBasicsTest() {
+        destroySchema(); // We don't need this fake schema with just "basics" table.
+
+        // Create the actual full Kea schema.
+        isc::db::test::createPgSQLSchema(true, true);
+    }
+
+    virtual ~PgSqlSchemaTest() {
+        // Clean up after ourselves.
+        isc::db::test::destroyPgSQLSchema(true, true);
+    }
+};
+
+/// @brief Checks if the schema version is really as expected.
+TEST_F(PgSqlSchemaTest, schemaVersion) {
+
+    PgSqlResultPtr r;
+    std::string sql = "SELECT version, minor FROM schema_version";
+    RUN_SQL(r, sql, PGRES_TUPLES_OK);
+    // There should be one row with 7,0 returned or whatever the latest schema is.
+    ASSERT_EQ(r->getRows(), 1) << "failed to check schema version, expected 1 row, have: "
+        << r->getRows();
+
+    int value = 0;
+    // Get row 0, column 0 (i.e. version field)
+    ASSERT_FALSE(PgSqlExchange::isColumnNull(*r, 0, 0));
+    ASSERT_NO_THROW(PgSqlExchange::getColumnValue(*r, 0, 0, value));
+    EXPECT_EQ(value, PG_SCHEMA_VERSION_MAJOR)
+        << "invalid schema version reported, major expected " << PG_SCHEMA_VERSION_MAJOR
+        << ", actual:" << value;
+
+    // Get row 0, column 1 (i.e. minor field)
+    ASSERT_FALSE(PgSqlExchange::isColumnNull(*r, 0, 1));
+    ASSERT_NO_THROW(PgSqlExchange::getColumnValue(*r, 0, 1, value));
+    EXPECT_EQ(value, PG_SCHEMA_VERSION_MINOR)
+        << "invalid schema version reported, minor expected " << PG_SCHEMA_VERSION_MINOR
+        << ", actual:" << value;
+
+}
+
+
 /// @brief Verifies that PgResultSet row and column meta-data is correct
 TEST_F(PgSqlBasicsTest, rowColumnBasics) {
     // We fetch the table contents, which at this point should be no rows.
@@ -709,6 +794,33 @@ TEST_F(PgSqlBasicsTest, intTest) {
     ASSERT_TRUE(PgSqlExchange::isColumnNull(*r, 0, INT_COL));
 }
 
+/// @brief Verify that we use the methods used for testing:
+/// amNull(), getInteger<T>(), getType()
+TEST_F(PgSqlBasicsTest, get) {
+    PsqlBindArray bind_array;
+
+    // The array itself is empty, its first column is not null
+    EXPECT_THROW(bind_array.amNull(), OutOfRange);
+    EXPECT_THROW(bind_array.getInteger<uint32_t>(), OutOfRange);
+    EXPECT_THROW(bind_array.getType(), OutOfRange);
+
+    // Now try again with proper values.
+    bind_array.add(123); // This will be converted to "123" string.
+    bind_array.addNull();
+    bind_array.add("sagittarius");
+    EXPECT_FALSE(bind_array.amNull(0)); // first column is not null
+    EXPECT_TRUE(bind_array.amNull(1)); // second column is null
+    EXPECT_FALSE(bind_array.amNull(2)); // third column is not null
+
+    EXPECT_EQ(123, bind_array.getInteger<uint32_t>(0)); // first column is 123
+    EXPECT_THROW(bind_array.getInteger<uint32_t>(1), BadValue);
+    EXPECT_THROW(bind_array.getInteger<uint32_t>(2), boost::bad_lexical_cast);
+
+    EXPECT_EQ(PsqlBindArray::TEXT_FMT, bind_array.getType(0));
+    EXPECT_EQ(PsqlBindArray::TEXT_FMT, bind_array.getType(1));
+    EXPECT_EQ(PsqlBindArray::TEXT_FMT, bind_array.getType(2));
+}
+
 /// @brief Verify that we can read and write TEXT columns
 TEST_F(PgSqlBasicsTest, textTest) {
     // Create a prepared statement for inserting TEXT
